========
Euphonic
========

Euphonic is a Python package that can efficiently calculate phonon
bandstructures, density of states and inelastic neutron scattering
intensities from force constants. The force constants can be read
from various sources, including CASTEP ``.castep_bin`` files, or Phonopy
``phonopy.yaml`` files. While Euphonic is primarily a library, multiple
command-line tools are also provided for convenient plotting of the above
quantities.

For more information, see the `docs <http://euphonic.readthedocs.io/en/latest/>`_.
